#!/bin/bash
#
# Input: .dmp
# Type: application/x-gzip
# Resource: core
#
# argv[1] = Input object
# argv[2] = Output object
# argv[3] = Temporary file, if applicable
# argv[4] = Filter command string, if applicable
#

TOOL=/opt/backtrace/bin/minidump-2-core
GZIP=gzip

if test ! -x "$TOOL"; then
       logger "coronerd requires $TOOL to be installed"
       exit 1
fi

# A conversion command was specified.  Unfortunately, the stack requires
# mapping in a file, which isn't supported for stdin, so it's necessary to
# store the result to a temp file.  This is used for compressed etc objects.
DMPPATH="$1"
INPATH="$DMPPATH"
ret=0
if [ -n "$3" ]; then
	INPATH="$3"
	$4 "$DMPPATH" "$INPATH"
	ret=$?
fi

if [ $ret -eq 0 ]; then
	set -o pipefail
	${TOOL} "$INPATH" | ${GZIP} -c > $2
	ret=$?
fi
[ "$DMPPATH" != "$INPATH" ] && rm -f $INPATH
[ $ret -ne 0 ] && rm -f $2
exit $ret
